@@ -16,6 +16,7 @@ use Apache2::Filter;
 use APR::Table;
 use Apache2::Const -compile =>
   qw(FORBIDDEN HTTP_UNAUTHORIZED REDIRECT OK DECLINED DONE SERVER_ERROR AUTH_REQUIRED HTTP_SERVICE_UNAVAILABLE);
+use URI;
 use base 'Lemonldap::NG::Handler::Main';
 
 use constant FORBIDDEN         => Apache2::Const::FORBIDDEN;
@@ -29,7 +30,7 @@ use constant AUTH_REQUIRED     => Apache2::Const::AUTH_REQUIRED;
 use constant MAINTENANCE       => Apache2::Const::HTTP_SERVICE_UNAVAILABLE;
 use constant BUFF_LEN          => 8192;
 
-our $VERSION = '2.0.6';
+our $VERSION = '2.16.3';
 
 # Set default logger
 use constant defaultLogger => 'Lemonldap::NG::Common::Logger::Apache2';
@@ -166,7 +167,7 @@ sub redirectFilter {
         $f->r->status( $class->REDIRECT );
         $f->r->status_line("303 See Other");
         $f->r->headers_out->unset('Location');
-        $f->r->err_headers_out->set( 'Location' => $url );
+        $f->r->err_headers_out->set( 'Location' => URI->new($url)->as_string );
         $f->ctx(1);
     }
     while ( $f->read( my $buffer, 1024 ) ) {
@@ -207,6 +208,12 @@ sub addToHtmlHead {
             $buffer .= $bdata if ($bdata);
             if ($seen_eos) {
                 my $len = length $buffer;
+                if ( !$len ) {
+
+                    # Empty body, decline processing to avoid an
+                    # empty content error
+                    return DECLINED;
+                }
                 $f->r->headers_out->set( 'Content-Length', $len );
                 $f->print($buffer) if ($buffer);
             }
