@@ -5,7 +5,7 @@ package Lemonldap::NG::Handler::PSGI::Main;
 
 use strict;
 use base 'Lemonldap::NG::Handler::Main';
-our $VERSION = '2.0.3';
+our $VERSION = '2.0.6';
 
 # Specific modules and constants for Test or CGI
 use constant FORBIDDEN         => 403;
@@ -41,6 +41,15 @@ sub set_user {
     push @{ $req->{respHeaders} }, 'Lm-Remote-User' => $user;
 }
 
+## @method void set_custom(string custom)
+# sets remote_custom in response headers
+# @param custom string custom_value
+sub set_custom {
+    my ( $class, $req, $custom ) = @_;
+    push @{ $req->{respHeaders} }, 'Lm-Remote-Custom' => $custom
+      if defined $custom;
+}
+
 ## @method void set_header_in(hash headers)
 # sets or modifies request headers
 # @param headers hash containing header names => header value
